@@ -12,10 +12,9 @@ from luwu.core.models.classifier import LuwuImageClassifier
 
 
 class LuwuPreTrainedImageClassifier(LuwuImageClassifier):
-    def __init__(self, net_name, *args, do_fine_tune=False, **kwargs):
+    def __init__(self, net_name, *args, **kwargs):
         super(LuwuPreTrainedImageClassifier, self).__init__(*args, **kwargs)
         self.net_name = net_name
-        self.do_fine_tune = do_fine_tune
 
     def build_model(self):
         pre_trained_net: tf.keras.Model = getattr(
