@@ -16,11 +16,14 @@ from luwu.core.preprocess.image.process import (
 
 
 class BaseDataGenerator(object):
-    def __init__(self, data_path, batch_size=32, image_size=224, shuffle=False):
+    def __init__(
+        self, data_path, batch_size=32, image_size=224, shuffle=False, do_fine_tune=True
+    ):
         self.data_path = data_path
         self.batch_size = batch_size
         self.image_size = image_size
         self.shuffle = shuffle
+        self.do_fine_tune = do_fine_tune
         self._steps = -1
         self.dataset = self.load_dataset()
 
@@ -40,14 +43,32 @@ class BaseDataGenerator(object):
 
 class ImageClassifierDataGnenrator(BaseDataGenerator):
     def load_dataset(self):
-        dataset = tf.data.TFRecordDataset(self.data_path)
-        dataset = dataset.map(extract_image_and_label_from_record)
-        dataset = dataset.map(lambda x, y: (x, y, self.image_size))
-        dataset = dataset.map(normalized_image_with_imagenet)
+        dataset = tf.data.TFRecordDataset(
+            self.data_path, num_parallel_reads=tf.data.experimental.AUTOTUNE
+        )
+        dataset = dataset.map(
+            extract_image_and_label_from_record,
+            num_parallel_calls=tf.data.experimental.AUTOTUNE,
+        )
+        dataset = dataset.map(
+            lambda x, y: (x, y, self.image_size),
+            num_parallel_calls=tf.data.experimental.AUTOTUNE,
+        )
+        if self.do_fine_tune:
+            dataset = dataset.map(
+                normalized_image_with_imagenet,
+                num_parallel_calls=tf.data.experimental.AUTOTUNE,
+            )
+        else:
+            dataset = dataset.map(
+                normalized_image, num_parallel_calls=tf.data.experimental.AUTOTUNE
+            )
         # todo:增加图像增广相关功能
         if self.shuffle:
             dataset = dataset.shuffle(10000)
-        dataset = dataset.prefetch(self.batch_size).batch(self.batch_size)
+        dataset = dataset.prefetch(buffer_size=tf.data.experimental.AUTOTUNE).batch(
+            self.batch_size
+        )
         # 计算总步数
         cnt = 0
         for _ in dataset:
