@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # @Author       : AaronJny
-# @LastEditTime : 2021-03-08
+# @LastEditTime : 2021-03-12
 # @FilePath     : /LuWu/luwu/utils/file_util.py
 # @Desc         :
 import os
@@ -11,3 +11,7 @@ def abspath(filepath):
         return os.path.abspath(os.path.expanduser(filepath))
     else:
         return ""
+
+
+def mkdirs(dirpath):
+    os.makedirs(dirpath, exist_ok=True)
